@@ -1,2 +1,5 @@
-coef.mcmc <- function(object, ...) 
+coef.mcmc <- 
+function(object, ...)
+{
     dclone:::coef.mcmc.list(as.mcmc.list(object), ...)
+}
